==> ep-framework-core-1.0.9-696185.tar: config/view_helpers.config.php <==
<?php
namespace Ep;

use Zend\ServiceManager\Factory\InvokableFactory;
use Zend;

return [
    'view_helpers' => [
        'aliases' => [
            'asset_url' => View\Helper\AssetUrl::class,
            'base_url'  => Zend\View\Helper\BasePath::class,

            'form'                => Form\View\Helper\Form::class,
            'form_button'         => Form\View\Helper\FormButton::class,
            'form_checkbox'       => Form\View\Helper\FormCheckbox::class,
            'form_close'          => Form\View\Helper\FormClose::class,
            'form_collection'     => Zend\Form\View\Helper\FormCollection::class,
            'form_control'        => Form\View\Helper\FormControl::class,
            'form_element'        => Form\View\Helper\FormElement::class,
            'form_element_errors' => Form\View\Helper\FormElementErrors::class,
            'form_group'          => Form\View\Helper\FormGroup::class,
            'form_input'          => Form\View\Helper\FormInput::class,
            'form_label'          => Form\View\Helper\FormLabel::class,
            'form_multi_checkbox' => Form\View\Helper\FormMultiCheckbox::class,
            'form_open'           => Form\View\Helper\FormOpen::class,
            'form_select'         => Form\View\Helper\FormSelect::class,
            'form_textarea'       => Form\View\Helper\FormTextarea::class,
        ],

        'factories' => [
            View\Helper\AssetUrl::class   => View\Helper\AssetUrlFactory::class,
            View\Helper\TwigBridge::class => InvokableFactory::class,

            Zend\View\Helper\BasePath::class => View\Helper\BasePathFactory::class,

            Form\View\Helper\Form::class              => InvokableFactory::class,
            Form\View\Helper\FormButton::class        => InvokableFactory::class,
            Form\View\Helper\FormCheckbox::class      => InvokableFactory::class,
            Form\View\Helper\FormClose::class         => InvokableFactory::class,
            Form\View\Helper\FormControl::class       => InvokableFactory::class,
            Form\View\Helper\FormElement::class       => InvokableFactory::class,
            Form\View\Helper\FormElementErrors::class => InvokableFactory::class,
            Form\View\Helper\FormGroup::class         => InvokableFactory::class,
            Form\View\Helper\FormInput::class         => InvokableFactory::class,
            Form\View\Helper\FormLabel::class         => InvokableFactory::class,
            Form\View\Helper\FormMultiCheckbox::class => InvokableFactory::class,
            Form\View\Helper\FormOpen::class          => InvokableFactory::class,
            Form\View\Helper\FormSelect::class        => InvokableFactory::class,
            Form\View\Helper\FormTextarea::class      => InvokableFactory::class,

            Zend\Form\View\Helper\FormCollection::class => InvokableFactory::class,
        ],
    ],
];

==> ep-framework-core-2.0.4-757951.tar: config/view_helpers.config.php <==
<?php
namespace Ep;

use Zend\ServiceManager\Factory\InvokableFactory;
use Zend;

return [
    'view_helpers' => [
        'aliases' => [
            'asset_url' => View\Helper\AssetUrl::class,
            'base_url'  => Zend\View\Helper\BasePath::class,
            'icon'      => View\Helper\Icon::class,

            'form'                => Form\View\Helper\Form::class,
            'form_button'         => Form\View\Helper\FormButton::class,
            'form_close'          => Form\View\Helper\FormClose::class,
            'form_collection'     => Form\View\Helper\FormCollection::class,
            'form_element'        => Form\View\Helper\FormElement::class,
            'form_element_errors' => Form\View\Helper\FormElementErrors::class,
            'form_group'          => Form\View\Helper\FormGroup::class,
            'form_icon'           => Form\View\Helper\FormIcon::class,
            'form_input'          => Form\View\Helper\FormInput::class,
            'form_label'          => Form\View\Helper\FormLabel::class,
            'form_multi_checkbox' => Form\View\Helper\FormMultiCheckbox::class,
            'form_open'           => Form\View\Helper\FormOpen::class,
            'form_select'         => Form\View\Helper\FormSelect::class,
            'form_textarea'       => Form\View\Helper\FormTextarea::class,
        ],

        'factories' => [
            View\Helper\AssetUrl::class   => View\Helper\AssetUrlFactory::class,
            View\Helper\TwigBridge::class => InvokableFactory::class,

            Zend\View\Helper\BasePath::class => View\Helper\BasePathFactory::class,
            View\Helper\Icon::class          => InvokableFactory::class,

            Form\View\Helper\Form::class              => InvokableFactory::class,
            Form\View\Helper\FormButton::class        => InvokableFactory::class,
            Form\View\Helper\FormCheckbox::class      => InvokableFactory::class,
            Form\View\Helper\FormClose::class         => InvokableFactory::class,
            Form\View\Helper\FormCollection::class    => InvokableFactory::class,
            Form\View\Helper\FormControl::class       => InvokableFactory::class,
            Form\View\Helper\FormElement::class       => InvokableFactory::class,
            Form\View\Helper\FormElementErrors::class => InvokableFactory::class,
            Form\View\Helper\FormGroup::class         => InvokableFactory::class,
            Form\View\Helper\FormIcon::class          => InvokableFactory::class,
            Form\View\Helper\FormInput::class         => InvokableFactory::class,
            Form\View\Helper\FormLabel::class         => InvokableFactory::class,
            Form\View\Helper\FormMultiCheckbox::class => InvokableFactory::class,
            Form\View\Helper\FormOpen::class          => InvokableFactory::class,
            Form\View\Helper\FormSelect::class        => InvokableFactory::class,
            Form\View\Helper\FormTextarea::class      => InvokableFactory::class,
        ],
    ],
];
